#include "dspout.h"

DspOut::DspOut( void )
:devstate(DeviceClosed)
{
}

DspOut::~DspOut( void )
{
}

void DspOut::setDeviceName( const QString &newDevName )
{
	devname = newDevName;
}

